caellion-python-commons: Packages

caellion-python-commons

Packages
Here are the packages with brief descriptions (if available):
[detail level 12345]

▼N caellion | This package wraps commons packages
▼N pycommons | This package wraps commons packages
▼N codeanalysis | This package provides facilities related to code analysis and reporting code analysis results
▼N reports | This module provides utlilities related to creating Jenkins' warnings-ng-plugin-compatible reports from codeanalysis
C ReportBuilder | This class provides a set of methods to create reports that are compatible with Jenkins' warnings-ng plugin
▼N encoding | This package provides facilities related to encoding of strings and numbers
▼N base36 | This module provides utlilities related to converting to/from base36 encoding
C InvalidCustomCharsetLengthException | This exception is raised when custom character set length
C InvalidCustomCharsetException | This exception is raised when more than exactly one instance of a given field is contained within field list
C InvalidInputStringException | This exception is raised when encountering a character not defined in custom charset in input string
C NumberNotPositiveOrZeroException | This exception is raised when non-positive integer is passed to encode function
C ValueTooLargeException | This exception is raised when encountering an integer over maximum size of 16 bytes
C Base36Coder | This class provides methods allowing conversion between integer, hexadecimal integer and base36 strings
▼N encryption | This package provides facilities related to encryption and decryption (but not hashing)
▼N tripledes | This module provides utilities related to or using 3DES symmetric encryption algorithm
C TripleDESECBMD5Key | This class provides implementation of triple DES algorithm which uses MD5 hash of password as a key (it uses 16-byte key so it is triple DES with 2 keys)
▼N hashing | This package provides facilities related to hashing
▼N file_hashing | This module provides utilities related to hashing files
C UnsupportedAlgorithmException | This exception is raised whenever provided algorithm is not one of allowed algorithms
C AlreadyDoneException | This exception is raised when hashing was requested on a FileHasher that has already finished hashing
C NotDoneYetException | This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet
C FileHasher | This class provides hashlib-based file hasher
▼N serializers | This package provides facilities related to serialization of objects
▼N datetime_serializer | This module provides various serializers for datetime.datetime object
C DateTimeIsoTimeSerializer | Implementation of DateTime serializer, using IsoTime as a serialized standard
C DateTimeUnixMillisSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with millisecond precision as serialized format
C DateTimeUnixMicrosSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with microsecond precision as serialized format
C DateTimeUnixSerializer | Implementation of DateTime serializer, using Unix-epoch based timestamp with second precision as serialized format
▼N stringutil | This package provides facilities related to formatting strings
▼N formatters | This module provides various string formatters
C InvalidDurationException | This exception is raised whenever provided duration is zero or negative
C NumberFormatting | This class provides various number formats
▼N unixpassword | This module provides utlilities related to creating, reading, writing and parsing of linux-style passwd/shadow file
C DuplicateFieldException | This exception is raised when more than exactly one instance of a given field is contained within field list
C EmptyFieldNameException | This exception is raised when an empty field name is encountered
C SeparatorEmptyException | This exception is raised when an empty separator string is encountered
C NewlineEmptyException | This exception is raised when an empty line separator string is encountered
C InvalidFileFormatException | This exception is raised when encountering invalid or non-uniform line
C UnixPasswordText | This class provides methods to read and write to linux-style passwd/shadow files, ability to parse shadow-style lines into dicts and identifying password hashing algorithms used in linux-style hash format
N parse | -tests This script parses test results, adding Linux or Windows prefix to test names
N parse-tests |
▼N tests | Test suite for caellion.pycommons
▼N test_codeanalysis_reports |
C TestCodeAnalysisReportsReportBuilder |
▼N test_encoding_base36 |
C TestEncodingBase36Coder |
▼N test_encryption_tripledes |
C TestSerializersDateTimeSerializer |
▼N test_hashing_file_hashing |
C TestHashingFileHasher |
▼N test_serializers_datetime_serializer |
C TestSerializersDateTimeSerializer |
▼N test_stringutil_formatters |
C TestStringUtilFormatters |
▼N test_stringutil_unixpassword |
C TestStringUtilUnixPasswordText |
N version-check |